// Implementation for ConfigLine
//
// Copyright Matthias Gaertner, Schenefeld, Germany, 2001
// You may use this code under the terms of the GPL.
// Updated packages may be found at http://www.rtner.de/sled/
//

#include <ConfigLine.h>

ConfigLine::ConfigLine()
{
	_hasData = false;
	_isComment = false;
	_isSection = false;
}

ConfigLine::~ConfigLine()
{
}

void ConfigLine::feed( IConfigurationSource *ics )
{
	SimpleString s;
	int zContinuation = 0;

	// Read one line from file character-wise.
	while( !ics->eof() )
	{
		int ic = ics->nextc();
		unsigned char c = (unsigned char)ic;

		if( ic < 0 )
		{
			break;
		}

		if( c == (unsigned char)'\\' )
		{
			zContinuation = 1;
		}
		else if( c == (unsigned char)'\n' )
		{
			if( zContinuation == 0 || zContinuation == 2 )
			{
				// Line termination found
				break;
			}
			else if( zContinuation == 1 )
			{
				s.append(' ');
				zContinuation = 2;
			}
		}
		else if( zContinuation == 2 &&
				( c == (unsigned char)' ' ||
				  c == (unsigned char)'\t' ) )
		{
			// ignore white space characters at beginning of line
		}
		else
		{
			zContinuation = 0;
			s.append(c);
		}
	}

	// Feed that line.
	feed( s );
}

void ConfigLine::feed( const char *s )
{
	feed( SimpleString( s ) );
}

void ConfigLine::feed( const unsigned char *s )
{
	feed( SimpleString( s ) );
}

void ConfigLine::feed( const SimpleString &s )
{
	_isComment = false;
	_hasData = false;
	_token.empty();
	_data.empty();

	SimpleString r( s );
	r.chopWhiteSpaceLeft();
	if( r.length() == 0 ||
		r.getAtC(0) == '#' )
	{
		_isComment = true;
		return;
	}

	int n = r.indexOf('=');
	if( n < 0 )
	{
		_hasData = false;
		_token.assign( r );

		if( _token.length() >=3 &&
			_token.getAt(0) == '[' &&
			_token.getAt(_token.length()-1) == ']' )
		{
			_isSection = true;
			_token.mid( 1, _token.length()-1 );
			_token.chopWhiteSpace();
		}
		else
		{
			_isSection = false;
		}
		return;
	}

	_isSection = false;
	_hasData = true;
	_token.assign( r );
	_token.left(n);
	_token.chopWhiteSpaceRight();

	_data.assign( r );
	_data.right(n+1);
	_data.chopWhiteSpaceLeft();
}

void ConfigLine::feed( const SimpleString *s )
{
	feed( SimpleString( *s ) );
}

bool ConfigLine::isComment() const
{
	return _isComment;
}

const SimpleString &ConfigLine::getToken() const
{
	return _token;
}

const SimpleString &ConfigLine::getData() const
{
	return _data;
}

bool ConfigLine::hasData() const
{
	return _hasData;
}

bool ConfigLine::isSection() const
{
	return _isSection;
}

/* */
