// Destructor and helper function implementation for IConfigLine
//
// Copyright Matthias Gaertner, Schenefeld, Germany, 2001
// You may use this code under the terms of the GPL.
// Updated packages may be found at http://www.rtner.de/sled/
//

#include <stdlib.h>				// for atoi
#include <IConfigLine.h>

IConfigLine::~IConfigLine()
{
}

int IConfigLine::scanYesNo( const char *token, bool *p )
{
	if( isComment() || isSection() || !hasData() )
	{
		return 301;
	}

	if( !getToken().equals( token ) )
	{
		return -1;
	}
	if( getData().equals("YES") || getData().equals("Yes") || getData().equals("yes") )
	{
		*p = true;
	}
	else if( getData().equals("NO") || getData().equals("No") || getData().equals("no") )
	{
		*p = false;
	}
	else
	{
		return 302;
	}
	return 0;
}

int IConfigLine::scanPositiveInt( const char *token, unsigned int *p )
{
	if( isComment() || isSection() || !hasData() )
	{
		return 310;
	}
	if( !getToken().equals( token ) )
	{
		return -1;
	}
	int i = atoi( getData().getPointerC() );
	if( i <= 0 )
	{
		return 311;
	}
	*p = (unsigned int)i;
	return 0;
}

int IConfigLine::scanNonNegativeInt( const char *token, unsigned int *p )
{
	if( isComment() || isSection() || !hasData() )
	{
		return 320;
	}
	if( !getToken().equals( token ) )
	{
		return -1;
	}
	int i = atoi( getData().getPointerC() );
	if( i < 0 )
	{
		return 321;
	}
	*p = (unsigned int)i;
	return 0;
}

int IConfigLine::scanNonEmptyString( const char *token, SimpleString *p )
{
	if( isComment() || isSection() || !hasData() )
	{
		return 330;
	}
	if( !getToken().equals( token ) )
	{
		return -1;
	}
	if( getData().length() == 0 )
	{
		return 331;
	}
	p->assign( getData() );
	return 0;
}

/* */
