// Interface definition for SimpleString
//
// Copyright Matthias Gaertner, Schenefeld, Germany, 2001
// You may use this code under the terms of the GPL.
// Updated packages may be found at http://www.rtner.de/sled/
//

#ifndef __SIMPLE_STRING_H
#define __SIMPLE_STRING_H

class SimpleString
{
public:
	SimpleString();
	SimpleString( unsigned int nStartLength );
	SimpleString( const unsigned char * );
	SimpleString( const char * );
	SimpleString( const unsigned char *, unsigned int length );
	SimpleString( const char *, unsigned int length );
	SimpleString( const SimpleString & );
	SimpleString( const SimpleString * );
	~SimpleString();

	SimpleString &append( unsigned char );
	SimpleString &append( char );
	SimpleString &append( const unsigned char * );
	SimpleString &append( const char * );
	SimpleString &append( const SimpleString & );
	SimpleString &append( const SimpleString * );

	SimpleString &empty( void );
	SimpleString &assign( const unsigned char * );
	SimpleString &assign( const char * );
	SimpleString &assign( const SimpleString & );
	SimpleString &assign( const SimpleString * );

	SimpleString &chopWhiteSpace( void );
	SimpleString &chopWhiteSpaceLeft( void );
	SimpleString &chopWhiteSpaceRight( void );

	bool isEmpty( void ) const;
	bool equals( const unsigned char * ) const;
	bool equals( const char * ) const;
	bool equals( const SimpleString & ) const;
	bool equals( const SimpleString * ) const;

	SimpleString &left( unsigned int offset );
	SimpleString &mid( unsigned int offsetLeft, unsigned int offsetRight );
	SimpleString &right( unsigned int offset );

	int indexOf( unsigned char ) const;
	int indexOf( char ) const;
	unsigned int length( void ) const;

	unsigned char getAt( unsigned int offset ) const;
	char getAtC( unsigned int offset ) const;

	const unsigned char *getPointer() const;
	const char *getPointerC() const;

	SimpleString &clone( void ) const;


protected:
	unsigned char *_s;
	unsigned int _n;
	unsigned int _nAllocated;

	void _append( const char *s, int m );
	void _init( const unsigned char *s, unsigned int length );
};

#endif /* __SIMPLE_STRING_H */

/* */
