// Implementation for SledConfiguration
//
// Copyright Matthias Gaertner, Schenefeld, Germany, 2001
// You may use this code under the terms of the GPL.
// Updated packages may be found at http://www.rtner.de/sled/
//

#include <SledConfiguration.h>
#include <ConfigGeneral.h>
#include <ConfigGroup.h>
#include <ConfigAction.h>
#include <ConfigLed.h>


SledConfiguration::SledConfiguration()
{
}

SledConfiguration::~SledConfiguration()
{
}

IConfigClass *SledConfiguration::createClassForSection( const SimpleString *section )
{
	IConfigClass *r = NULL;

	if( section->equals("") )
	{
		r = new ConfigGeneral();
	}
	else if( section->equals("GROUP") )
	{
		r = new ConfigGroup();
	}
	else if( section->equals("ACTION") )
	{
		r = new ConfigAction();
	}
	else if( section->equals("LED") )
	{
		r = new ConfigLed();
	}
	return r;
}

void SledConfiguration::notifySectionStop( const SimpleString *name, IConfigClass *c )
{
	bool fDeleteObject = false;

	// Whenever we have processed an ACTION section, we move the object to its associated group
	if( name->equals("ACTION") )
	{
		ConfigAction *ca = (ConfigAction*)c;
		const SimpleString &actionGroup = ca->getGroup();

		// Find relevant group object
		const struct _ConfigurationListElement *p = _l;
		while( p != NULL )
		{
			if( p->_name->equals("GROUP") )
			{
				ConfigGroup *cg = (ConfigGroup*)(p->_c);
				if( cg->getName().equals( actionGroup ) )
				{
					// Remove ACTION element from main list
					struct _ConfigurationListElement *q = unlinkSectionByClass( ca );
					q->_c = NULL;
					delete q;

					// Add current ACTION element to group object
					cg->addSubelement( ca );
					return;
				}
			}
			p = p->_next;
		}
		fDeleteObject = true;
	}
	else if( name->equals("LED") )
	{
		ConfigLed *cl = (ConfigLed*)c;

		// Find relevant group object
		const struct _ConfigurationListElement *p = _l;
		while( p != NULL )
		{
			if( p->_name->isEmpty() )
			{
				// Remove LED element from main list
				struct _ConfigurationListElement *q = unlinkSectionByClass( cl );
				q->_c = NULL;
				delete q;

				// Add current LED element to general object
				((SledConfigClass*)(p->_c))->addSubelement( cl );
				return;
			}
			p = p->_next;
		}
		fDeleteObject = true;
	}

	if( fDeleteObject )
	{
		// Error, matching group not found. Unlink and delete ACTION/LED thing.
		delete unlinkSectionByClass( c );
	}
}

IConfigClass *SledConfiguration::getSection( SimpleString *s ) const
{
	// Create a new section object for every file section even if same name
	return NULL;
}

ConfigGeneral *SledConfiguration::getGeneral( void ) const
{
	return (ConfigGeneral*)(_l->_c);
}

/* */
